FileExtension

Enum FileExtension 

#[non_exhaustive]
pub enum FileExtension {
Show 213 variants ThreeFr, ThreeG2, ThreeGp, ThreeGpp, SevenZ, Aac, Abw, Ac3, Ace, Ai, Aif, Aifc, Aiff, Alz, Amr, Arc, Arj, Arw, Au, Avi, Avif, Azw, Azw3, Azw4, Bmp, Bz, Bz2, Cab, Caf, Cavs, Cbc, Cbr, Cbz, Cdr, Cgm, Chm, Cpio, Cr2, Cr3, Crw, Csv, Dcr, Deb, Djvu, Dmg, Dng, Doc, Docm, Docx, Dot, Dotx, Dps, Dss, Dv, Dvr, Dwf, Dwg, Dxf, Emf, Eml, Eot, Eps, Epub, Erf, Et, Fb2, Flac, Flv, Gif, Gz, Heic, Heif, Htm, Html, Htmlz, Hwp, Hwpx, Icns, Ico, Img, Iso, Jar, Jfif, Jpeg, Jpg, Key, Lha, Lit, Lrf, Lwp, Lz, Lzma, Lzo, M2ts, M4a, M4b, M4v, Md, Mkv, Mobi, Mod, Mos, Mov, Mp3, Mp4, Mpeg, Mpg, Mrw, Mts, Mxf, Nef, Numbers, Odd, Odg, Odp, Ods, Odt, Oeb, Oga, Ogg, Ogv, Opus, Orf, Otf, Pages, Pdb, Pdf, Pef, Pml, Png, Pot, Potx, Ppm, Pps, Ppsx, Ppt, Pptm, Pptx, Prc, Ps, Psb, Psd, Pub, Raf, Rar, Raw, Rb, Rm, Rmvb, Rpm, Rst, Rtf, Rw2, Rz, Sda, Sdc, Sdw, Sf2, Sfark, Sk, Sk1, Snb, Svg, Svgz, Swf, Tar, Tar7z, TarBz, TarBz2, TarGz, TarLzo, TarXz, TarZ, Tbz, Tbz2, Tcr, Tex, Tga, Tgz, Tif, Tiff, Ts, Ttf, Txt, Txtz, Tz, Tzo, Vob, Voc, Vsd, Vtt, Wav, Weba, Webm, Webp, Wma, Wmf, Wmv, Woff, Woff2, Wpd, Wps, Wtv, X3f, Xcf, Xls, Xlsm, Xlsx, Xps, Xz, Z, Zabw, Zip,
}
Supported CloudConvert file extension tokens.

Values serialize to the lowercase extension token CloudConvert expects, without a leading dot. The list is derived from CloudConvert’s operations metadata endpoint.

use cloudconvert_sdk::FileExtension;

assert_eq!(FileExtension::Pdf.as_str(), "pdf");
assert_eq!(".TAR.GZ".parse::<FileExtension>().unwrap(), FileExtension::TarGz);
assert_eq!(
    serde_json::to_value(FileExtension::SevenZ).unwrap(),
    serde_json::json!("7z")
);

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ThreeFr



ThreeG2



ThreeGp



ThreeGpp



SevenZ



Aac



Abw



Ac3



Ace



Ai



Aif



Aifc



Aiff



Alz



Amr



Arc



Arj



Arw



Au



Avi



Avif



Azw



Azw3



Azw4



Bmp



Bz



Bz2



Cab



Caf



Cavs



Cbc



Cbr



Cbz



Cdr



Cgm



Chm



Cpio



Cr2



Cr3



Crw



Csv



Dcr



Deb



Djvu



Dmg



Dng



Doc



Docm



Docx



Dot



Dotx



Dps



Dss



Dv



Dvr



Dwf



Dwg



Dxf



Emf



Eml



Eot



Eps



Epub



Erf



Et



Fb2



Flac



Flv



Gif



Gz



Heic



Heif



Htm



Html



Htmlz



Hwp



Hwpx



Icns



Ico



Img



Iso



Jar



Jfif



Jpeg



Jpg



Key



Lha



Lit



Lrf



Lwp



Lz



Lzma



Lzo



M2ts



M4a



M4b



M4v



Md



Mkv



Mobi



Mod



Mos



Mov



Mp3



Mp4



Mpeg



Mpg



Mrw



Mts



Mxf



Nef



Numbers



Odd



Odg



Odp



Ods



Odt



Oeb



Oga



Ogg



Ogv



Opus



Orf



Otf



Pages



Pdb



Pdf



Pef



Pml



Png



Pot



Potx



Ppm



Pps



Ppsx



Ppt



Pptm



Pptx



Prc



Ps



Psb



Psd



Pub



Raf



Rar



Raw



Rb



Rm



Rmvb



Rpm



Rst



Rtf



Rw2



Rz



Sda



Sdc



Sdw



Sf2



Sfark



Sk



Sk1



Snb



Svg



Svgz



Swf



Tar



Tar7z



TarBz



TarBz2



TarGz



TarLzo



TarXz



TarZ



Tbz



Tbz2



Tcr



Tex



Tga



Tgz



Tif



Tiff



Ts



Ttf



Txt



Txtz



Tz



Tzo



Vob



Voc



Vsd



Vtt



Wav



Weba



Webm



Webp



Wma



Wmf



Wmv



Woff



Woff2



Wpd



Wps



Wtv



X3f



Xcf



Xls



Xlsm



Xlsx



Xps



Xz



Z



Zabw



Zip

Implementations

Source

impl FileExtension

pub const ALL: &'static [Self]

All known file extensions in sorted order.

pub const fn as_str(self) -> &'static str

Returns the extension token CloudConvert expects.

pub fn parse(value: &str) -> Result<Self, ParseFileExtensionError>

Parses a CloudConvert extension token.

Leading dots, surrounding whitespace and ASCII case differences are normalized before matching.

use cloudconvert_sdk::FileExtension;

assert_eq!(FileExtension::parse(" .PDF ").unwrap(), FileExtension::Pdf);