pub struct InvalidBuilderState {
pub kind: InvalidBuilderStateKind,
pub builder: &'static str,
pub method: &'static str,
}Expand description
Error returned when a job builder method is called in an invalid state.
Fields
kind: InvalidBuilderStateKindbuilder: &'static strmethod: &'static strTrait Implementations
Sourceimpl Clone for InvalidBuilderState
impl Clone for InvalidBuilderState
Sourcefn clone(&self) -> InvalidBuilderState
fn clone(&self) -> InvalidBuilderState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for InvalidBuilderState
Sourceimpl Debug for InvalidBuilderState
impl Debug for InvalidBuilderState
Sourceimpl Display for InvalidBuilderState
impl Display for InvalidBuilderState
impl Eq for InvalidBuilderState
Sourceimpl Error for InvalidBuilderState
impl Error for InvalidBuilderState
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl From<InvalidBuilderState> for Error
impl From<InvalidBuilderState> for Error
Sourcefn from(source: InvalidBuilderState) -> Self
fn from(source: InvalidBuilderState) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for InvalidBuilderState
impl PartialEq for InvalidBuilderState
Sourcefn eq(&self, other: &InvalidBuilderState) -> bool
fn eq(&self, other: &InvalidBuilderState) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for InvalidBuilderState