pub struct OAuthClient { /* private fields */ }Expand description
OAuth client used to start authorization flows and exchange tokens.
Implementations
Sourceimpl OAuthClient
impl OAuthClient
pub fn new( client_id: impl Into<String>, client_secret: OAuthClientSecret, ) -> Result<Self>
pub fn with_http_client( client_id: impl Into<String>, client_secret: OAuthClientSecret, http: Client, ) -> Result<Self>
pub fn with_endpoints(self, authorize_url: Url, token_url: Url) -> Self
pub fn client_id(&self) -> &str
pub fn token_url(&self) -> &Url
Builds an authorization-code flow URL for the given redirect URI and scopes.
pub fn implicit_url( &self, redirect_uri: impl AsRef<str>, scopes: impl IntoIterator<Item = OAuthScope>, ) -> Result<Url>
pub fn implicit_url_with_state( &self, redirect_uri: impl AsRef<str>, scopes: impl IntoIterator<Item = OAuthScope>, state: impl Into<String>, ) -> Result<Url>
Sourcepub async fn exchange_code(
&self,
code: impl Into<String>,
redirect_uri: impl Into<String>,
) -> Result<OAuthTokenResponse>
pub async fn exchange_code( &self, code: impl Into<String>, redirect_uri: impl Into<String>, ) -> Result<OAuthTokenResponse>
Exchanges an authorization code for access and optional refresh tokens.
Sourcepub async fn refresh_access_token(
&self,
refresh_token: &OAuthRefreshToken,
) -> Result<OAuthTokenResponse>
pub async fn refresh_access_token( &self, refresh_token: &OAuthRefreshToken, ) -> Result<OAuthTokenResponse>
Refreshes an access token using a stored refresh token.