TaskRequest

Struct TaskRequest 

pub struct TaskRequest { /* private fields */ }
Serialized task request used by job and standalone task APIs.

Most jobs can be built with crate::JobCreateRequest::linear or crate::JobCreateRequest::graph. Use TaskRequest directly for standalone task APIs, explicit low-level job construction, or operations that do not have a first-class typed builder yet.

use cloudconvert_sdk::{FileExtension, JobCreateRequest};

let request = JobCreateRequest::graph(|job| {
    let import = job.import_url("https://example.test/input.docx");
    job.convert(&import, FileExtension::Pdf);
})
.build();

let payload = serde_json::to_value(request).unwrap();
assert_eq!(payload["tasks"]["convert"]["input"], "import-url");

Implementations

Source

impl TaskRequest

pub fn import_url(url: impl Into<String>) -> Self

Creates an import/url task request.

pub fn import_upload() -> Self

Creates an import/upload task request.

pub fn import_base64( file: impl Into<String>, filename: impl Into<String>, ) -> Self

Creates an import/base64 task request.

pub fn import_raw(file: impl Into<String>, filename: impl Into<String>) -> Self

Creates an import/raw task request.

pub fn import_s3( bucket: impl Into<String>, region: impl Into<String>, access_key_id: impl Into<String>, secret_access_key: impl Into<String>, ) -> Self

Creates an import/s3 task request.

pub fn import_azure_blob( storage_account: impl Into<String>, container: impl Into<String>, ) -> Self

Creates an import/azure/blob task request.

pub fn import_google_cloud_storage( project_id: impl Into<String>, bucket: impl Into<String>, client_email: impl Into<String>, private_key: impl Into<String>, ) -> Self

Creates an import/google-cloud-storage task request.

pub fn import_openstack( auth_url: impl Into<String>, username: impl Into<String>, password: impl Into<String>, region: impl Into<String>, container: impl Into<String>, ) -> Self

Creates an import/openstack task request.

pub fn import_sftp(host: impl Into<String>, username: impl Into<String>) -> Self

Creates an import/sftp task request.

pub fn convert( input: impl Into<Input>, output_format: impl Into<String>, ) -> Self

Creates a convert task request.

pub fn optimize(input: impl Into<Input>) -> Self

Creates an optimize task request.

pub fn watermark(task: WatermarkTask) -> Self

Creates a watermark task request from a typed watermark task.

pub fn capture_website( url: impl Into<String>, output_format: impl Into<String>, ) -> Self

Creates a capture-website task request.

pub fn thumbnail( input: impl Into<Input>, output_format: impl Into<String>, ) -> Self

Creates a thumbnail task request.

pub fn metadata(input: impl Into<Input>) -> Self

Creates a metadata task request.

pub fn metadata_write(input: impl Into<Input>) -> Self

Creates a metadata/write task request.

pub fn merge(input: impl Into<Input>, output_format: impl Into<String>) -> Self

Creates a merge task request.

pub fn archive( input: impl Into<Input>, output_format: impl Into<String>, ) -> Self

Creates an archive task request.

pub fn command( input: impl Into<Input>, engine: impl Into<String>, command: impl Into<String>, arguments: impl Into<String>, ) -> Self

Creates a command task request.

pub fn pdf_a(input: impl Into<Input>) -> Self

Creates a pdf/a task request.

pub fn pdf_x(input: impl Into<Input>) -> Self

Creates a pdf/x task request.

pub fn pdf_ocr(input: impl Into<Input>) -> Self

Creates a pdf/ocr task request.

pub fn pdf_encrypt(input: impl Into<Input>) -> Self

Creates a pdf/encrypt task request.

pub fn pdf_decrypt(input: impl Into<Input>) -> Self

Creates a pdf/decrypt task request.

pub fn pdf_split_pages(input: impl Into<Input>) -> Self

Creates a pdf/split-pages task request.

pub fn pdf_extract_pages(input: impl Into<Input>) -> Self

Creates a pdf/extract-pages task request.

pub fn pdf_rotate_pages(input: impl Into<Input>) -> Self

Creates a pdf/rotate-pages task request.

pub fn export_url(input: impl Into<Input>) -> Self

Creates an export/url task request.

pub fn export_s3( input: impl Into<Input>, bucket: impl Into<String>, region: impl Into<String>, access_key_id: impl Into<String>, secret_access_key: impl Into<String>, ) -> Self

Creates an export/s3 task request.

pub fn export_azure_blob( input: impl Into<Input>, storage_account: impl Into<String>, container: impl Into<String>, ) -> Self

Creates an export/azure/blob task request.

pub fn export_google_cloud_storage( input: impl Into<Input>, project_id: impl Into<String>, bucket: impl Into<String>, client_email: impl Into<String>, private_key: impl Into<String>, ) -> Self

Creates an export/google-cloud-storage task request.

pub fn export_openstack( input: impl Into<Input>, auth_url: impl Into<String>, username: impl Into<String>, password: impl Into<String>, region: impl Into<String>, container: impl Into<String>, ) -> Self

Creates an export/openstack task request.

pub fn export_sftp( input: impl Into<Input>, host: impl Into<String>, username: impl Into<String>, ) -> Self

Creates an export/sftp task request.

pub fn export_upload(input: impl Into<Input>, url: impl Into<String>) -> Self

Creates an export/upload task request.

pub fn custom(operation: impl Into<String>) -> GenericTask

Starts a custom task request for an operation not typed by the SDK.

use cloudconvert_sdk::TaskRequest;
use serde_json::json;

let task = TaskRequest::custom("custom/op")
    .field("input", "import-file")
    .field("custom_option", json!(true));

assert_eq!(task.operation(), "custom/op");
pub fn try_from_payload<T>(payload: T) -> Result<Self>
where T: TaskPayload,

Converts a typed task payload into a TaskRequest.

pub fn from_payload<T>(payload: T) -> Self
where T: TaskPayload,

Converts a typed task payload into a TaskRequest.

Panics only if an SDK-owned typed task serializes to something other than a JSON object.

pub fn operation(&self) -> &str

Returns the CloudConvert operation name.

pub fn payload(&self) -> &Map<String, Value>

Returns the task payload without the injected operation field.